@@ -66,96 +66,6 @@ test_that("Check that basic output are the same as the provided matrix",
 })
 
 
-test_that("Check that dimensions are correct with cgroup usage",
-{
-  mx <- matrix(1:6, ncol=3)
-  colnames(mx) <- sprintf("Col %s", LETTERS[1:NCOL(mx)])
-  table_str <- htmlTable(mx,
-                         cgroup=c("a", "b"),
-                         n.cgroup=c(1, 2))
-  parsed_table <- readHTMLTable(table_str)[[1]]
-  expect_equal(ncol(parsed_table), ncol(mx) + 1,
-               info = "Cols did not match")
-  expect_equal(nrow(parsed_table),
-               nrow(mx), info="Rows did not match")
-
-  expect_warning(htmlTable(mx,
-                           cgroup=c("a", "b", "c"),
-                           n.cgroup=c(1, 2, 0)))
-
-  expect_error(htmlTable(mx,
-                         cgroup=c("a", "b", "c"),
-                         n.cgroup=c(1, 2, 10)))
-
-  table_str <- htmlTable(mx,
-                         cgroup=rbind(c("aa", NA),
-                                      c("a", "b")),
-                         n.cgroup=rbind(c(2, NA),
-                                        c(1, 2)))
-  parsed_table <- readHTMLTable(table_str)[[1]]
-  expect_equal(ncol(parsed_table), ncol(mx) + 1,
-               info="Cols did not match for multilevel cgroup")
-
-
-  table_str <- htmlTable(mx,
-                         cgroup=rbind(c("aa", "bb"),
-                                      c("a", "b")),
-                         n.cgroup=rbind(c(2, 1),
-                                        c(1, 2)))
-  parsed_table <- readHTMLTable(table_str)[[1]]
-  expect_equal(ncol(parsed_table), ncol(mx) + 2,
-               info="Cols did not match for multilevel cgroup")
-
-  table_str <- htmlTable(mx,
-                         cgroup=c("a", "b"),
-                         n.cgroup=c(2, 1),
-                         tspanner=c("First spanner",
-                                    "Secon spanner"),
-                         n.tspanner=c(1,1))
-  expect_match(table_str, "td[^>]*colspan='4'[^>]*>First spanner",
-               info="The expected number of columns should be 4")
-  expect_match(table_str, "td[^>]*colspan='4'[^>]*>Secon spanner",
-               info="The expected number of columns should be 4")
-
-  expect_error(htmlTable(mx,
-                         cgroup=c("a", "b"),
-                         n.cgroup=c(2, 1),
-                         tspanner=c("First spanner",
-                                    "Secon spanner"),
-                         n.tspanner=c(1,2)))
-
-
-  mx <- rbind(mx,
-              mx,
-              mx,
-              mx)
-  table_str <- htmlTable(mx,
-                         rnames = LETTERS[1:nrow(mx)],
-                         cgroup=rbind(c("aa", "bb"),
-                                      c("a", "b")),
-                         n.cgroup=rbind(c(2, 1),
-                                        c(1, 2)),
-                         rgroup=paste(1:4, "rgroup"),
-                         n.rgroup=rep(2, 4),
-                         tspanner=c("First tspanner",
-                                    "Second tspanner"),
-                         n.tspanner=c(4,4))
-
-  expect_match(table_str, "td[^>]*colspan='6'[^>]*>1 rgroup",
-               info="The expected number of columns should be 6")
-  expect_match(table_str, "td[^>]*colspan='6'[^>]*>2 rgroup",
-               info="The expected number of columns should be 6")
-
-  parsed_table <- readHTMLTable(table_str)[[1]]
-  expect_equal(as.character(parsed_table[1,1]),
-               "First tspanner")
-  expect_equal(as.character(parsed_table[2,1]),
-               "1 rgroup")
-  expect_equal(as.character(parsed_table[8,1]),
-               "Second tspanner")
-  expect_equal(as.character(parsed_table[9,1]),
-               "3 rgroup")
-})
 
 test_that("rnames = FALSE it should skip those",
 {
@@ -378,3 +288,19 @@ test_that("Problem with naming in stringr 1.0.0", {
                regexp = "^font-weight: 900; background-color: #f7f7f7")
 
 })
+
+test_that("Handling data.frames with factors",{
+  tmp <- data.frame(a = 1:3,
+                    b = factor(x = 1:3,
+                               labels = c("Unique_Factor_1",
+                                          "Factor_2",
+                                          "Factor_3")))
+
+  str <- htmlTable(tmp)
+  expect_true(grepl("Unique_Factor_1", str))
+
+  tmp <- data.frame(a = 1,
+                    b = factor(x = 1,
+                               labels = c("1.2")))
+  expect_true(txtRound(tmp)$b == 1)
+})
